<?PHP
/**
 * Describes a PuQI message.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Describes a PuQI message.
 */
final class MDPuqiMessage implements JsonSerializable {

    public readonly MDPuqiCheckSection $section;    // Section of object data that is described by the message.
    public readonly MDPuqiMessageStatus $status;
    public readonly string $message;    // Text message.
    public readonly int $score;

    /**
     * Provides the option to serialize as a string during json_encode().
     *
     * @return array{section: MDPuqiCheckSection, status: MDPuqiMessageStatus, message: string, score: integer}
     */
    public function jsonSerialize():array {

        return [
            'section' => $this->section,
            'status' => $this->status,
            'message' => $this->message,
            'score' => $this->score
        ];

    }

    /**
     * Constructor.
     *
     * @param MDPuqiCheckSection  $section Section described by this message.
     * @param MDPuqiMessageStatus $status  Status.
     * @param string              $message Message.
     * @param integer             $score   Score impact of the message.
     *
     * @return void
     */
    public function __construct(MDPuqiCheckSection $section, MDPuqiMessageStatus $status, string $message, int $score) {

        $this->section = $section;
        $this->status = $status;
        $this->message = $message;
        $this->score = $score;

    }
}
